# Originally imported from Fedora Rawhide.
Name:           debconf
Version:        1.5.86
Release:        %mkrel 2
Summary:        Debian configuration management system

Group:          System/Packaging
License:        BSD
URL:            https://packages.debian.org/sid/debconf
Source0:        https://ftp.debian.org/debian/pool/main/d/%{name}/%{name}_%{version}.tar.xz
Patch0:         debconf-1.5.32-no-utf8-to-pod2man.patch
BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  po4a >= 0.23
BuildRequires:  gettext >= 0.13
BuildRequires:  perl-libintl-perl
BuildRequires:  perl-Gtk3
# Not actual requirements, although listed at
# https://ftp.debian.org/debian/pool/main/d/debconf/debconf_1.5.32.dsc
#BuildRequires:  debhelper >= 7.0.50
#BuildRequires:  perl-libintl
#BuildRequires:  po-debconf

%description
Debconf is a configuration management system for Debian
packages. Packages use Debconf to ask questions when
they are installed.

%package doc
Summary:        Debconf documentation
Group:          Documentation
Requires:       %{name} = %{version}-%{release}

%description doc
This package contains lots of additional documentation for Debconf,
including the debconf user's guide, documentation about using
different backend databases via the /etc/debconf.conf file, and a
developer's guide to debconf.

%package i18n
Summary:        Full internationalization support for debconf
Group:          System/Packaging
Requires:       %{name} = %{version}-%{release}

%description i18n
This package provides full internationalization for debconf,
including translations into all available languages, support
for using translated debconf templates, and support for
proper display of multibyte character sets.

%package utils
Summary:        This package contains some small utilities for debconf developers
Group:          System/Packaging
Requires:       %{name} = %{version}-%{release}

%description utils
This package contains some small utilities for debconf developers.

%package -n python%{python3_pkgversion}-%{name}
Summary:        python3 for debconf
%{?python_provide:%python_provide python%{python3_pkgversion}-%{name}}

%description -n python%{python3_pkgversion}-%{name}
This package contains the python3 for debconf.


%prep
%autosetup -p1 -n work


%build
%make_build

%install
make install prefix=%{buildroot}
make install-i18n prefix=%{buildroot}
make install-utils prefix=%{buildroot}
#make install-python3 prefix=%%{buildroot}
install -d %{buildroot}%{python3_sitelib}
install -m 0644 debconf.py  %{buildroot}%{python3_sitelib}

make install-rest prefix=%{buildroot}

mkdir -p \
        %{buildroot}/%{perl_vendorlib} \
        %{buildroot}/%{_mandir}/man{1,3,5,7,8} \
        %{buildroot}/%{_mandir}/de/man{1,3,5,7,8} \
        %{buildroot}/%{_mandir}/fr/man{1,3,5,7,8} \
        %{buildroot}/%{_mandir}/ru/man{1,3,5,7,8} \
        %{buildroot}/%{_mandir}/pt_BR/man{1,3,8}

#if "%{_datadir}/perl5" != "%{perl_vendorlib}"
#mv %{buildroot}/%{_datadir}/perl5/Debconf %{buildroot}/%{perl_vendorlib}/.
#mv %{buildroot}/%{_datadir}/perl5/Debian %{buildroot}/%{perl_vendorlib}/.
#endif

chmod 755 %{buildroot}/%{_datadir}/%{name}/confmodule*

# Base and i18n man pages
for man in \
        "debconf-apt-progress" \
        "debconf-communicate" \
        "debconf-copydb" \
        "debconf-escape" \
        "debconf-set-selections" \
        "debconf-show" \
        "debconf" \
        "dpkg-preconfigure" \
        "dpkg-reconfigure"; do

    for level in 1 8; do
        for lang in de fr pt_BR ru; do
            if test -f doc/man/gen/$man.$lang.$level; then
                short_lang=`echo "$lang" | sed 's/_.*//'`
                install -m 644 doc/man/gen/$man.$lang.$level %{buildroot}/%{_mandir}/$lang/man$level/$man.$level
                echo "%lang($short_lang) %{_mandir}/$lang/man$level/$man.$level*" >> "man-i18n.lang"
            fi
        done
        test -f doc/man/gen/$man.$level && \
            install -m 644 doc/man/gen/$man.$level %{buildroot}/%{_mandir}/man$level/$man.$level
    done
done

# Doc foo
for man in \
        "Debconf::Client::ConfModule" \
        "confmodule" \
        "debconf.conf" \
        "debconf-devel" \
        "debconf"; do

    for level in 3 5 7; do
        for lang in de fr pt_BR ru; do
            if test -f doc/man/$man.$lang.$level*; then
                short_lang=`echo "$lang" | sed 's/_.*//'`
                install -m 644 doc/man/$man.$lang.$level* %{buildroot}/%{_mandir}/$lang/man$level/$man.$level
                echo "%lang($short_lang) %{_mandir}/$lang/man$level/$man.$level*" >> "man-doc.lang"
            fi
        done
        test -f doc/man/$man.$level && \
            install -m 644 doc/man/$man.$level %{buildroot}/%{_mandir}/man$level/$man.$level
    done
done

# Utils man pages
for man in get-selections \
            getlang \
            loadtemplate \
            mergetemplate; do
    for lang in de fr pt_BR ru; do
        short_lang=`echo "$lang" | sed 's/_.*//'`
        if test -f doc/man/gen/debconf-$man.$lang.1; then
            install -m 644 doc/man/gen/debconf-$man.$lang.1 %{buildroot}/%{_mandir}/$lang/man1/debconf-$man.1
            echo "%lang($short_lang) %{_mandir}/$lang/man1/debconf-$man.1*" >> "man-utils.lang"
        fi
    done
    test -f doc/man/gen/debconf-$man.1 && \
        install -m 644 doc/man/gen/debconf-$man.1 %{buildroot}/%{_mandir}/man1/debconf-$man.1
done

%find_lang debconf

%files
%doc doc/README doc/EXAMPLES doc/CREDITS doc/README.translators doc/README.LDAP doc/TODO
%doc debian/changelog debian/README.Debian
%license debian/copyright
%config(noreplace) %{_sysconfdir}/debconf.conf
%{_bindir}/debconf
%{_bindir}/debconf-apt-progress
%{_bindir}/debconf-communicate
%{_bindir}/debconf-copydb
%{_bindir}/debconf-escape
%{_bindir}/debconf-set-selections
%{_bindir}/debconf-show
%{_sbindir}/dpkg-preconfigure
%{_sbindir}/dpkg-reconfigure
%exclude /usr/lib/python3
%{perl_vendorlib}/Debconf
%{perl_vendorlib}/Debian
%{_datadir}/%{name}
%{_mandir}/man1/debconf-apt-progress.1*
%{_mandir}/man1/debconf-communicate.1*
%{_mandir}/man1/debconf-copydb.1*
%{_mandir}/man1/debconf-escape.1*
%{_mandir}/man1/debconf-set-selections.1*
%{_mandir}/man1/debconf-show.1*
%{_mandir}/man1/debconf.1*
%{_mandir}/man8/dpkg-preconfigure.8*
%{_mandir}/man8/dpkg-reconfigure.8*
%{_datadir}/pixmaps/debian-logo.png

%files doc -f man-doc.lang
%doc samples/
%doc doc/CREDITS doc/README doc/README.LDAP doc/TODO
%doc debian/changelog
%doc debian/copyright
%doc doc/debconf.schema
%doc doc/hierarchy.txt
%doc doc/namespace.txt
%doc doc/passthrough.txt
%{_mandir}/man3/confmodule.3*
%{_mandir}/man5/debconf.conf.5*
%{_mandir}/man7/debconf-devel.7*
%{_mandir}/man7/debconf.7*

%files i18n -f man-i18n.lang -f debconf.lang
%doc debian/changelog debian/copyright debian/README.Debian

%files utils -f man-utils.lang
%doc debian/changelog debian/copyright debian/README.Debian
%{_bindir}/debconf-get-selections
%{_bindir}/debconf-getlang
%{_bindir}/debconf-loadtemplate
%{_bindir}/debconf-mergetemplate
%{_mandir}/man1/debconf-get-selections.1*
%{_mandir}/man1/debconf-getlang.1*
%{_mandir}/man1/debconf-loadtemplate.1*
%{_mandir}/man1/debconf-mergetemplate.1*

%files -n python%{python3_pkgversion}-%{name}
%{python3_sitelib}/*


%changelog
* Tue Mar 04 2025 wally <wally> 1.5.86-2.mga10
+ Revision: 2160356
- rebuild for python3.13

* Tue Feb 27 2024 daviddavid <daviddavid> 1.5.86-1.mga10
+ Revision: 2044556
- new version: 1.5.86
- rebuild for py3.12

* Wed Mar 23 2022 umeabot <umeabot> 1.5.79-3.mga9
+ Revision: 1821679
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 1.5.79-2.mga9
+ Revision: 1782748
- Rebuild for python-3.10

* Mon Jan 17 2022 mrambo3501 <mrambo3501> 1.5.79-1.mga9
+ Revision: 1768796
- version 1.5.79

* Sat Mar 27 2021 tv <tv> 1.5.74-2.mga9
+ Revision: 1710966
- Rebuild for python 3.9

* Mon May 25 2020 shlomif <shlomif> 1.5.74-1.mga8
+ Revision: 1587588
- New version 1.5.74

* Tue Feb 18 2020 umeabot <umeabot> 1.5.73-2.mga8
+ Revision: 1539340
- Mageia 8 Mass Rebuild

* Sat Dec 07 2019 shlomif <shlomif> 1.5.73-1.mga8
+ Revision: 1465003
- New version 1.5.73

* Sun Oct 13 2019 tv <tv> 1.5.71-3.mga8
+ Revision: 1452813
- rebuild for python-3.8
- drop python2 subpkg

* Mon Apr 15 2019 daviddavid <daviddavid> 1.5.71-1.mga7
+ Revision: 1390600
- new version: 1.5.71

* Tue Jan 08 2019 shlomif <shlomif> 1.5.69-2.mga7
+ Revision: 1352421
- Rebuild for python3 3.7

* Fri Sep 21 2018 tv <tv> 1.5.69-1.mga7
+ Revision: 1294642
- drop perl-qt4 (no more used)
- specs cleaning
- add python[23] mappings
- new release
- adapt to new perl
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sat Jun 18 2016 pterjan <pterjan> 1.5.57-3.mga6
+ Revision: 1022111
- Rebuild for perl 5.22.2

* Fri Feb 19 2016 umeabot <umeabot> 1.5.57-2.mga6
+ Revision: 969771
- Mageia 6 Mass Rebuild

* Thu Sep 10 2015 shlomif <shlomif> 1.5.57-1.mga6
+ Revision: 875467
- New version 1.5.57

* Wed Oct 15 2014 umeabot <umeabot> 1.5.53-3.mga5
+ Revision: 741153
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.53-2.mga5
+ Revision: 678702
- Mageia 5 Mass Rebuild

* Wed May 21 2014 shlomif <shlomif> 1.5.53-1.mga5
+ Revision: 624634
- New version 1.5.53

* Sat Oct 19 2013 umeabot <umeabot> 1.5.50-2.mga4
+ Revision: 526384
- Mageia 4 Mass Rebuild

* Tue Jun 04 2013 kharec <kharec> 1.5.50-1.mga4
+ Revision: 436851
- update to 1.5.50
- drop python version support patch, upstream add it
- update file list

* Tue Jan 22 2013 fwang <fwang> 1.5.42-3.mga3
+ Revision: 390722
- update rpm group

* Fri Jan 11 2013 umeabot <umeabot> 1.5.42-2.mga3
+ Revision: 348713
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Aug 25 2012 shlomif <shlomif> 1.5.42-1.mga3
+ Revision: 283833
- Fix groups
- Remove stray require
- Fix
- imported package debconf


* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.42-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Jun 10 2012 Petr Pisar <ppisar@redhat.com> - 1.5.42-6
- Perl 5.16 rebuild

* Sun May 13 2012 Oron Peled <oron@actcom.co.il> - 1.5.42-5
- Bump release to match f17, f16 builds

* Sat May 12 2012 Oron Peled <oron@actcom.co.il> - 1.5.42-4
- Fix find_lang for man-pages. It is not smart enough to do
  it all in one swoop. So we generate the expected results
  manually (during installation)
- Fix exclude of python3 (picked wrong directory on x86-64

* Tue May  1 2012 Oron Peled <oron@actcom.co.il> - 1.5.42-3
- Added --with-man and --all-name to find_lang
- Use wild-cards for language directories of man-pages

* Thu Apr 12 2012 Oron Peled <oron@actcom.co.il> - 1.5.42-2
- Added find_lang stuff
- Don't specify man-pages compression
- Added BR python
- Added BR perl-Qt (for KDE frontend)

* Mon Mar 26 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 1.5.42-1
- New upstream version

* Tue Sep  7 2010 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 1.5.32-4
- Fix available python interpreters (4)
- Fix %%install (4)
- Fix build requirements (3)
- Include doc, i18n and utils packages (2)
- First package (1)
